import {
  hotUpdateSetupComponent,
  loadSetupComponent,
  transformSetupComponent
} from "./chunk-M3L2IV3Y.mjs";
import {
  SETUP_COMPONENT_ID_REGEX
} from "./chunk-ZUROAGHW.mjs";

// src/index.ts
import { createUnplugin } from "unplugin";
import { createFilter } from "@rollup/pluginutils";
import { REGEX_SETUP_SFC, REGEX_SRC_FILE } from "@vue-macros/common";
function resolveOption(options) {
  return {
    include: [REGEX_SRC_FILE],
    exclude: [REGEX_SETUP_SFC],
    root: process.cwd(),
    ...options
  };
}
var name = "unplugin-vue-setup-component";
var src_default = createUnplugin((userOptions = {}) => {
  const options = resolveOption(userOptions);
  const filter = createFilter(options.include, options.exclude);
  const setupComponentContext = {};
  return {
    name,
    enforce: "pre",
    resolveId(id) {
      if (SETUP_COMPONENT_ID_REGEX.test(id))
        return id;
    },
    loadInclude(id) {
      return SETUP_COMPONENT_ID_REGEX.test(id);
    },
    load(id) {
      return loadSetupComponent(id, setupComponentContext, options.root);
    },
    transformInclude(id) {
      return filter(id);
    },
    transform(code, id) {
      try {
        return transformSetupComponent(code, id, setupComponentContext);
      } catch (err) {
        this.error(`${name} ${err}`);
      }
    },
    vite: {
      configResolved(config) {
        options.root = config.root;
      },
      handleHotUpdate: (ctx) => {
        if (filter(ctx.file)) {
          return hotUpdateSetupComponent(ctx, setupComponentContext);
        }
      }
    }
  };
});

export {
  src_default
};
